@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2007 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIMAP_IMAPSET_H
@@ -22,15 +9,14 @@
 
 #include "kimap_export.h"
 
-#include <QtCore/QByteArray>
-#include <QtCore/QDebug>
-#include <QtCore/QList>
-#include <QtCore/QMetaType>
-#include <QtCore/QSharedDataPointer>
+#include <QByteArray>
+#include <QDebug>
+#include <QList>
+#include <QMetaType>
+#include <QSharedDataPointer>
 
 namespace KIMAP
 {
-
 /**
   Represents a single interval in an ImapSet.
   This class is implicitly shared.
@@ -41,12 +27,12 @@ public:
     /**
      * Describes the ids stored in the interval.
      */
-    typedef qint64 Id;
+    using Id = qint64;
 
     /**
       A list of ImapInterval objects.
     */
-    typedef QList<ImapInterval> List;
+    using List = QList<ImapInterval>;
 
     /**
       Constructs an interval that covers all positive numbers.
@@ -134,7 +120,7 @@ private:
 };
 
 /**
-  Represents a set of natural numbers (1->\f$\infty\f$) in a as compact as possible form.
+  Represents a set of natural numbers (1->∞) in a as compact as possible form.
   Used to address Akonadi items via the IMAP protocol or in the database.
   This class is implicitly shared.
 */
@@ -144,7 +130,7 @@ public:
     /**
      * Describes the ids stored in the set.
      */
-    typedef qint64 Id;
+    using Id = qint64;
 
     /**
       Constructs an empty set.
@@ -224,6 +210,15 @@ public:
     */
     bool isEmpty() const;
 
+    /**
+     * Optimizes the ImapSet by sorting and merging overlapping intervals.
+     *
+     * Normally you shouldn't need to call this method. KIMAP will make sure
+     * to opimize the ImapSet before serializing it to string and sending it
+     * to the IMAP server.
+     */
+    void optimize();
+
 private:
     class Private;
     QSharedDataPointer<Private> d;
